==> neper-1.8.0.tgz: neper-1.8.0/src/Utils/GeoUtils/Tess2Geo/Tess2Geo.h <==
/* This file is part of the 'neper' program. */
/* Copyright (C) 2004-2009, Romain Quey. */
/* See the COPYING file in the top-level directory. */

#include<stdio.h>
#include<stdlib.h>
#include<math.h>

#include"../../Structs/structTess.h"
#include"../../Structs/structNodes.h"
#include"../../Structs/structMesh.h"
#include"../../Structs/structGeo.h"
#include"../../BoardUtils/BoardUtils0.h"
#include"../../SpaceUtils/SpaceUtils0.h"
#include"../../DisplayUtils/DisplayUtils0.h"
#include"../Various/Various0.h"

#include"Tess2Geo0.h"

extern void GeoGenDet (struct TESS, struct GEO *);
extern void GeoAlloc (struct GEO *);
extern void Tess2GeoVer (struct TESS, struct GEO *);
extern void Tess2GeoVerQty (struct TESS, struct GEO *);
extern void Tess2GeoVerCoo (struct TESS, struct GEO *);
extern void Tess2GeoVerEdge (struct TESS, struct GEO *);
extern void Tess2GeoVerBound (struct TESS, struct GEO *);
extern void Tess2GeoEdge (struct TESS, struct GEO *);
extern void Tess2GeoEdgeQty (struct TESS, struct GEO *);
extern void Tess2GeoEdgeVerNb (struct TESS, struct GEO *);
extern void Tess2GeoEdgeFace (struct TESS, struct GEO *);
extern void Tess2GeoEdgeLength (struct GEO *);
extern void CalcEdgeLength (struct GEO *, int);
extern void Tess2GeoEdgeDel (struct TESS, struct GEO *);
extern void Tess2GeoFace (struct TESS, struct GEO *);
extern void Tess2GeoFaceQty (struct TESS, struct GEO *);
extern void Tess2GeoFaceGerm (struct TESS, struct GEO *);
extern void Tess2GeoFaceVer (struct TESS, struct GEO *);
extern void Tess2GeoFaceEdge (struct TESS, struct GEO *);
extern void Tess2GeoFaceFF (struct TESS, struct GEO *);
extern void Tess2GeoFaceEq (struct TESS, struct GEO *);
extern void Tess2GeoFaceBound (struct GEO *);
extern void Tess2GeoPoly (struct TESS, struct GEO *);
extern void Tess2GeoPolyQty (struct TESS, struct GEO *);
extern void Tess2GeoPolyFace (struct TESS, struct GEO *);
extern void Tess2GeoDomainSize (struct TESS, struct GEO *);

==> neper-1.8.1.tgz: neper-1.8.1/src/Utils/GeoUtils/Tess2Geo/Tess2Geo.h <==
/* This file is part of the 'neper' program. */
/* Copyright (C) 2003-2009, Romain Quey. */
/* See the COPYING file in the top-level directory. */

#include<stdio.h>
#include<stdlib.h>
#include<math.h>

#include"../../Structs/structAll.h"
#include"../../BoardUtils/BoardUtils0.h"
#include"../../SpaceUtils/SpaceUtils0.h"
#include"../../DisplayUtils/DisplayUtils0.h"
#include"../Various/Various0.h"

#include"Tess2Geo0.h"

extern void GeoGenDet (struct TESS, struct GEO *);
extern void GeoAlloc (struct GEO *);
extern void Tess2GeoVer (struct TESS, struct GEO *);
extern void Tess2GeoVerQty (struct TESS, struct GEO *);
extern void Tess2GeoVerCoo (struct TESS, struct GEO *);
extern void Tess2GeoVerEdge (struct TESS, struct GEO *);
extern void Tess2GeoVerBound (struct TESS, struct GEO *);
extern void Tess2GeoEdge (struct TESS, struct GEO *);
extern void Tess2GeoEdgeQty (struct TESS, struct GEO *);
extern void Tess2GeoEdgeVerNb (struct TESS, struct GEO *);
extern void Tess2GeoEdgeFace (struct TESS, struct GEO *);
extern void Tess2GeoEdgeLength (struct GEO *);
extern void CalcEdgeLength (struct GEO *, int);
extern void Tess2GeoEdgeDel (struct TESS, struct GEO *);
extern void Tess2GeoFace (struct TESS, struct GEO *);
extern void Tess2GeoFaceQty (struct TESS, struct GEO *);
extern void Tess2GeoFaceGerm (struct TESS, struct GEO *);
extern void Tess2GeoFaceVer (struct TESS, struct GEO *);
extern void Tess2GeoFaceEdge (struct TESS, struct GEO *);
extern void Tess2GeoFaceFF (struct TESS, struct GEO *);
extern void Tess2GeoFaceEq (struct TESS, struct GEO *);
extern void Tess2GeoFaceBound (struct GEO *);
extern void Tess2GeoPoly (struct TESS, struct GEO *);
extern void Tess2GeoPolyQty (struct TESS, struct GEO *);
extern void Tess2GeoPolyFace (struct TESS, struct GEO *);
extern void Tess2GeoDomainSize (struct TESS, struct GEO *);
